==> cms-db_v0.8.1.tar.gz: admin/locales/de/common.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    For a full list of authors, see info.php
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['common'] = array();

# Start: Buttons
$locale['common']['button_ok'] = 'OK';
$locale['common']['button_save'] = 'Speichern';
$locale['common']['button_cancel'] = 'Abbrechen';
$locale['common']['button_yes'] = 'Ja';
$locale['common']['button_no'] = 'Nein';
$locale['common']['button_send'] = 'Senden';
$locale['common']['button_reset'] = 'Formular zurücksetzen';
# End: Buttons

# Start: Categories
$locale['common']['desc_pages'] = 'Seitenverwaltung';
$locale['common']['desc_files'] = 'Dateiverwaltung';
$locale['common']['desc_includes'] = 'Includes';
$locale['common']['desc_settings'] = 'Einstellungen';
$locale['common']['desc_template'] = 'Template/Design';
$locale['common']['desc_space'] = 'Speicherplatz';
$locale['common']['desc_fileperms'] = 'Dateiberechtigungen';
$locale['common']['desc_backup'] = 'Sicherheitskopien';
$locale['common']['desc_guestbook'] = 'Gästebucheinträge';
$locale['common']['desc_blog'] = 'Blog';
$locale['common']['desc_stats'] = 'Statistiken';
$locale['common']['desc_recyclebin'] = 'Recycling-Center';
# End: Categories

# Start: Settings
$locale['common']['link_usersettings'] = 'Benutzer';
$locale['common']['link_commonsettings'] = 'Allgemein';
$locale['common']['link_urlsettings'] = 'URL';
$locale['common']['link_ftpsettings'] = 'FTP';
$locale['common']['link_adminsettings'] = 'Erscheinungsbild';
$locale['common']['link_localesettings'] = 'Sprache';
$locale['common']['desc_settings-saved'] = 'Die Einstellungen wurden gespeichert.';
# End: Settings

# Start: Errors
$locale['common']['title_error'] = 'Fehler';
$locale['common']['desc_error-open-file'] = 'Kann die Datei <i>%s</i> nicht öffnen.';
$locale['common']['desc_error-write-file'] = 'Kann nicht in die Datei <i>%s</i> schreiben.';
$locale['common']['desc_error-fileperms'] = 'Sie haben keine Schreibrechte für die Datei <i>%s</i>.';
$locale['common']['desc_error-move-file'] = 'Die Datei konnte nicht verschoben werden.';
$locale['common']['desc_error-input'] = 'Sie haben nicht alle benötigten Felder ausgefüllt.';
$locale['common']['link_back'] = 'Zurück';
# End: Errors

# Start: WYMeditor
$locale['common']['wymeditor_align_left'] = 'Links ausgerichtet';
$locale['common']['wymeditor_align_right'] = 'Rechts ausgerichtet';
$locale['common']['wymeditor_align_clear'] = 'Ausrichtung aufheben';
$locale['common']['wymeditor_attributes'] = 'Attribute';
$locale['common']['wymeditor_new_window'] = 'Neues Fenster';
$locale['common']['wymeditor_new_window_title'] = 'Eine Verknüpfung in einem neuen Fenster öffnen';
$locale['common']['wymeditor_anchor'] = 'Anker (ID)';
$locale['common']['wymeditor_anchor_title'] = 'Einen Anker hinzufügen (id-Attribut)';
$locale['common']['wymeditor_value'] = 'Wert:';
$locale['common']['wymeditor_wrong_element'] = 'Dieses Attribut kann dem ausgewählten Element nicht zugewiesen werden.';
$locale['common']['wymeditor_error_external'] = 'Diese Funktion ist standardmäßig deaktiviert.';
$locale['common']['wymeditor_error_external_why'] = 'Warum?';
$locale['common']['wymeditor_error_external_more1'] = 'Das Attribut um einen Verweis in einem neuen Fenster zu öffnen wurde in XHTML 1.0 Strict entfernt.';
$locale['common']['wymeditor_error_external_more2'] = 'Deshalb muss ein Trick verwendet werden, um Verknüpfungen in einem neuen Fenster zu öffnen. Dieser Trick benötigt Javascript und könnte mit Popup-Blockern Probleme bereiten.';
$locale['common']['wymeditor_error_external_more3'] = 'Bitte verwenden Sie diese Funktion sehr vorsichtig!';
# End: WYMeditor

# Start: Editor
$locale['common']['desc_javascript'] = 'Sie müssen Javascript aktivieren, um die Funktion zum Einfügen von Adressen oder den WYSIWYM-Editor zu verwenden.';
$locale['common']['desc_insert-page'] = 'Seiten';
$locale['common']['desc_insert-file'] = 'Dateien';
# End: Editor

# Start: Autosave
$locale['common']['desc_autosave-version'] = 'Dies ist ein zuvor gespeicherter Entwurf der Seite.';
$locale['common']['desc_autosave-blog'] = 'Dies ist ein zuvor gespeicherter Entwurf des Blogeintrags.';
$locale['common']['link_discard-changes'] = 'Änderungen verwerfen';
$locale['common']['link_delete-draft'] = 'Entwurf löschen';
$locale['common']['button_publish'] = 'Veröffentlichen';
$locale['common']['button_savedraft'] = 'Entwurf speichern';
$locale['common']['desc_autosave-saved'] = 'Gespeichert.';
$locale['common']['desc_autosave-saving'] = 'Speichern...';
$locale['common']['desc_autosave-skipped'] = 'Speichern übersprungen.';
$locale['common']['desc_autosave-next'] = 'Nächstes Speichern in  %s Sekunden...';
$locale['common']['desc_draft'] = 'Entwurf';
# End: Autosave

# Start: Password
$locale['common']['label_oldpw'] = 'Altes Passwort:';
$locale['common']['label_newpw'] = 'Neues Passwort:';
$locale['common']['desc_repeat'] = 'Passwort wiederholen:';
$locale['common']['desc_error-invalid-data'] = 'Die eingegebenen Daten sind ungültig.';
# End: Password

# Start: Dates
$locale['common']['date_day1'] = 'Sonntag';
$locale['common']['date_day2'] = 'Montag';
$locale['common']['date_day3'] = 'Dienstag';
$locale['common']['date_day4'] = 'Mittwoch';
$locale['common']['date_day5'] = 'Donnerstag';
$locale['common']['date_day6'] = 'Freitag';
$locale['common']['date_day7'] = 'Samstag';
$locale['common']['date_month1'] = 'Januar';
$locale['common']['date_month2'] = 'Februar';
$locale['common']['date_month3'] = 'März';
$locale['common']['date_month4'] = 'April';
$locale['common']['date_month5'] = 'Mai';
$locale['common']['date_month6'] = 'Juni';
$locale['common']['date_month7'] = 'Juli';
$locale['common']['date_month8'] = 'August';
$locale['common']['date_month9'] = 'September';
$locale['common']['date_month10'] = 'Oktober';
$locale['common']['date_month11'] = 'November';
$locale['common']['date_month12'] = 'Dezember';
$locale['common']['date_dateformat'] = '+day,  +d. +month +y';
$locale['common']['date_timeformat'] = '+h:+m';
# End: Dates

# Start: Insert
$locale['common']['desc_cantinsert'] = 'Die URL konnte nicht eingefügt werden. Stattdessen können Sie die Zieladresse aus dem Link in der Liste oder vom Menü der Website kopieren.';
# End: Insert

# Start: CSRF Protection Error
$locale['common']['title_csrfprotection'] = 'Ungültiger oder fehlender Prüfcode';
$locale['common']['desc_csrfprotection'] = 'Der Prüfcode für die angeforderte Seite wurde nicht korrekt übertragen. Das könnte möglicherweise auf einen CSRF-Angriff hindeuten. Ein anderer Grund kann ein Programmierfehler sein.';
# End: CSRF Protection Error

$locale['common']['label_username'] = 'Benutzername';
$locale['common']['label_password'] = 'Passwort';

$locale['common']['link_next'] = 'Weiter';
$locale['common']['link_edit'] = 'bearbeiten';
$locale['common']['link_rename'] = 'umbenennen';
$locale['common']['link_delete'] = 'löschen';
$locale['common']['desc_action'] = 'Aktion';

$locale['common']['title_editpage'] = 'Seite bearbeiten';

$locale['common']['button_create'] = 'Erstellen';

$locale['common']['link_close'] = 'Schließen';
?>

==> cms-db_v0.9.tar.gz: admin/locales/de/common.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    For a full list of authors, see info.php
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['common'] = array();

$locale['common']['button_ok'] = 'OK';
$locale['common']['button_save'] = 'Speichern';
$locale['common']['button_cancel'] = 'Abbrechen';
$locale['common']['button_yes'] = 'Ja';
$locale['common']['button_no'] = 'Nein';
$locale['common']['button_send'] = 'Senden';
$locale['common']['button_reset'] = 'Formular zurücksetzen';
$locale['common']['desc_pages'] = 'Seitenverwaltung';
$locale['common']['desc_files'] = 'Dateiverwaltung';
$locale['common']['desc_includes'] = 'Includes';
$locale['common']['desc_settings'] = 'Einstellungen';
$locale['common']['desc_template'] = 'Designvorlage';
$locale['common']['desc_space'] = 'Speicherplatz';
$locale['common']['desc_fileperms'] = 'Dateiberechtigungen';
$locale['common']['desc_backup'] = 'Datensicherung';
$locale['common']['desc_guestbook'] = 'Gästebucheinträge';
$locale['common']['desc_blog'] = 'Blog';
$locale['common']['desc_stats'] = 'Statistiken';
$locale['common']['desc_recyclebin'] = 'Recycling-Center';
$locale['common']['link_usersettings'] = 'Benutzer';
$locale['common']['link_commonsettings'] = 'Allgemein';
$locale['common']['link_urlsettings'] = 'URL';
$locale['common']['link_updatesettings'] = 'Aktualisierungen';
$locale['common']['link_adminsettings'] = 'Erscheinungsbild';
$locale['common']['link_editorsettings'] = 'Editor';
$locale['common']['link_localesettings'] = 'Sprache';
$locale['common']['desc_settings-saved'] = 'Die Einstellungen wurden gespeichert.';
$locale['common']['label_autoupdate'] = 'Automatische Überprüfung auf Aktualisierungen aktivieren';
$locale['common']['desc_autoupdate'] = 'Nach jeder Anmeldung wird cms -db nach Aktualisierungen suchen und Sie benachrichtigen, falls eine neue Version zum Herunterladen bereitsteht.';
$locale['common']['desc_updatecheck'] = 'Die IP-Adresse Ihres Servers und die Versionsnummer Ihrer Installation von cms -db werden zum Aktualisierungs-Server übertragen. Die IP-Adresse wird möglicherweise in den Zugriffsprotokollen des Webservers gespeichert, aber keine der Daten werden in irgendeiner anderen Form gespeichert oder sogar verarbeitet.';
$locale['common']['title_error'] = 'Fehler';
$locale['common']['desc_error-open-file'] = 'Die Datei <i>%s</i> konnte nicht geöffnet werden.';
$locale['common']['desc_error-write-file'] = 'Die Datei <i>%s</i> konnte nicht geschrieben werden.';
$locale['common']['desc_error-fileperms'] = 'Sie haben keine Schreibrechte für die Datei <i>%s</i>.';
$locale['common']['desc_error-move-file'] = 'Die Datei konnte nicht verschoben werden.';
$locale['common']['link_back'] = 'Zurück';
$locale['common']['desc_error-input'] = 'Bitte geben Sie die folgenden erforderlichen Details an:';
$locale['common']['desc_error-spamprotection'] = 'Die Anfrage konnte nicht bearbeitet werden. Bitte warten Sie mindestens 10 Sekunden und versuchen Sie es erneut.';
$locale['common']['wymeditor_stretch_image'] = 'Volle Breite';
$locale['common']['wymeditor_align_left'] = 'Links ausgerichtet';
$locale['common']['wymeditor_align_right'] = 'Rechts ausgerichtet';
$locale['common']['wymeditor_align_clear'] = 'Ausrichtung aufheben';
$locale['common']['wymeditor_attributes'] = 'Attribute';
$locale['common']['wymeditor_new_window'] = 'Neues Fenster';
$locale['common']['wymeditor_new_window_title'] = 'Eine Verknüpfung in einem neuen Fenster öffnen';
$locale['common']['wymeditor_anchor'] = 'Anker (ID)';
$locale['common']['wymeditor_anchor_title'] = 'Einen Anker hinzufügen (id-Attribut)';
$locale['common']['wymeditor_value'] = 'Wert:';
$locale['common']['wymeditor_wrong_element'] = 'Dieses Attribut kann dem ausgewählten Element nicht zugewiesen werden.';
$locale['common']['wymeditor_error_external'] = 'Diese Funktion ist in den Voreinstellungen nicht aktiviert.';
$locale['common']['wymeditor_error_external_why'] = 'Warum?';
$locale['common']['wymeditor_error_external_more1'] = 'Die Möglichkeit zum Öffnen eines Verweises in einem neuen Fenster wurde im Standard XHTML 1.0 Strict entfernt.';
$locale['common']['wymeditor_error_external_more2'] = 'Deshalb muss ein Trick verwendet werden, um Verknüpfungen in einem neuen Fenster zu öffnen. Dieser Trick benötigt Javascript und könnte mit Popup-Blockern Probleme bereiten.';
$locale['common']['wymeditor_error_external_more3'] = 'Sie sollten diese Funktion deshalb mit Bedacht einsetzen!';
$locale['common']['desc_javascript'] = 'Sie müssen Javascript aktivieren, um die Funktion zum Einfügen von Adressen oder den WYSIWYM-Editor zu verwenden.';
$locale['common']['desc_insert-page'] = 'Seiten';
$locale['common']['desc_insert-file'] = 'Dateien';
$locale['common']['desc_autosave-version'] = 'Dies ist ein zuvor gespeicherter Entwurf der Seite.';
$locale['common']['desc_autosave-blog'] = 'Dies ist ein zuvor gespeicherter Entwurf des Blogeintrags.';
$locale['common']['link_discard-changes'] = 'Änderungen verwerfen';
$locale['common']['link_delete-draft'] = 'Entwurf löschen';
$locale['common']['button_publish'] = 'Veröffentlichen';
$locale['common']['button_savedraft'] = 'Entwurf speichern';
$locale['common']['desc_autosave-saved'] = 'Gespeichert.';
$locale['common']['desc_autosave-saving'] = 'Speichern...';
$locale['common']['desc_autosave-skipped'] = 'Speichern übersprungen.';
$locale['common']['desc_autosave-next'] = 'Nächstes Speichern in  %s Sekunden...';
$locale['common']['desc_draft'] = 'Entwurf';
$locale['common']['label_oldpw'] = 'Altes Passwort:';
$locale['common']['label_newpw'] = 'Neues Passwort:';
$locale['common']['desc_repeat'] = 'Passwort wiederholen:';
$locale['common']['desc_error-invalid-data'] = 'Die eingegebenen Daten sind ungültig.';
$locale['common']['date_day1'] = 'Sonntag';
$locale['common']['date_day2'] = 'Montag';
$locale['common']['date_day3'] = 'Dienstag';
$locale['common']['date_day4'] = 'Mittwoch';
$locale['common']['date_day5'] = 'Donnerstag';
$locale['common']['date_day6'] = 'Freitag';
$locale['common']['date_day7'] = 'Samstag';
$locale['common']['date_month1'] = 'Januar';
$locale['common']['date_month2'] = 'Februar';
$locale['common']['date_month3'] = 'März';
$locale['common']['date_month4'] = 'April';
$locale['common']['date_month5'] = 'Mai';
$locale['common']['date_month6'] = 'Juni';
$locale['common']['date_month7'] = 'Juli';
$locale['common']['date_month8'] = 'August';
$locale['common']['date_month9'] = 'September';
$locale['common']['date_month10'] = 'Oktober';
$locale['common']['date_month11'] = 'November';
$locale['common']['date_month12'] = 'Dezember';
$locale['common']['date_dateformat'] = '+day,  +d. +month +y';
$locale['common']['date_timeformat'] = '+h:+m';
$locale['common']['desc_cantinsert'] = 'Die URL konnte nicht eingefügt werden. Stattdessen können Sie die Zieladresse aus dem Link in der Liste oder vom Menü der Website kopieren.';
$locale['common']['title_csrfprotection'] = 'Ungültiger oder fehlender Prüfcode';
$locale['common']['desc_csrfprotection'] = 'Der Prüfcode für die angeforderte Seite wurde nicht korrekt übertragen. Das könnte möglicherweise auf einen CSRF-Angriff hindeuten. Ein anderer Grund kann ein Programmierfehler sein.';
$locale['common']['licensenotes1'] = 'Dieses Programm ist freie Software. Sie können es unter den Bedingungen der GNU General Public License, wie von der Free Software Foundation veröffentlicht, weitergeben und/oder modifizieren, entweder gemäß Version 3 der Lizenz oder (nach Ihrer Wahl) jeder späteren Version.';
$locale['common']['licensenotes2'] = 'Die Veröffentlichung dieses Programms erfolgt in der Hoffnung, dass es Ihnen von Nutzen sein wird, aber OHNE IRGENDEINE GARANTIE, sogar ohne die implizite Garantie der MARKTREIFE oder der VERWENDBARKEIT FÜR EINEN BESTIMMTEN ZWECK. Einzelheizen finden Sie in der GNU General Public License.';
$locale['common']['licensenotes3'] = 'Sie sollten ein Exemplar der GNU General Public License zusammen mit diesem Programm erhalten haben. Falls nicht, siehe http://www.gnu.org/licenses/.';
$locale['common']['label_username'] = 'Benutzername';
$locale['common']['label_password'] = 'Passwort';
$locale['common']['link_next'] = 'Weiter';
$locale['common']['link_open'] = 'öffnen';
$locale['common']['link_edit'] = 'bearbeiten';
$locale['common']['link_rename'] = 'umbenennen';
$locale['common']['link_delete'] = 'löschen';
$locale['common']['desc_action'] = 'Aktion';
$locale['common']['title_editpage'] = 'Seite bearbeiten';
$locale['common']['button_create'] = 'Erstellen';
$locale['common']['link_close'] = 'Schließen';
